@@ -23,18 +23,20 @@
 #include <algorithm>
 #include <string>
 #include <vector>
-#include "ola/base/Macro.h"
 #include "ola/Clock.h"
 #include "ola/Constants.h"
 #include "ola/Logging.h"
+#include "ola/base/Array.h"
+#include "ola/base/Macro.h"
+#include "ola/network/IPV4Address.h"
 #include "ola/network/Interface.h"
 #include "ola/network/InterfacePicker.h"
-#include "ola/network/IPV4Address.h"
 #include "ola/network/MACAddress.h"
 #include "ola/network/NetworkUtils.h"
+#include "ola/rdm/RDMEnums.h"
 #include "ola/rdm/ResponderHelper.h"
 #include "ola/rdm/ResponderSensor.h"
-#include "ola/rdm/RDMEnums.h"
+#include "ola/strings/Utils.h"
 
 namespace ola {
 namespace rdm {
@@ -78,7 +80,7 @@ bool ResponderHelper::ExtractUInt32(const RDMRequest *request,
 }
 
 
-const RDMResponse *ResponderHelper::GetDeviceInfo(
+RDMResponse *ResponderHelper::GetDeviceInfo(
     const RDMRequest *request,
     uint16_t device_model,
     rdm_product_category product_category,
@@ -130,7 +132,7 @@ const RDMResponse *ResponderHelper::GetDeviceInfo(
       queued_message_count);
 }
 
-const RDMResponse *ResponderHelper::GetDeviceInfo(
+RDMResponse *ResponderHelper::GetDeviceInfo(
     const RDMRequest *request,
     uint16_t device_model,
     rdm_product_category product_category,
@@ -150,7 +152,7 @@ const RDMResponse *ResponderHelper::GetDeviceInfo(
       sub_device_count, sensor_count, queued_message_count);
 }
 
-const RDMResponse *ResponderHelper::GetProductDetailList(
+RDMResponse *ResponderHelper::GetProductDetailList(
     const RDMRequest *request,
     const vector<rdm_product_detail> &product_details,
     uint8_t queued_message_count) {
@@ -173,7 +175,7 @@ const RDMResponse *ResponderHelper::GetProductDetailList(
       queued_message_count);
 }
 
-const RDMResponse *ResponderHelper::GetPersonality(
+RDMResponse *ResponderHelper::GetPersonality(
     const RDMRequest *request,
     const PersonalityManager *personality_manager,
     uint8_t queued_message_count) {
@@ -200,7 +202,7 @@ const RDMResponse *ResponderHelper::GetPersonality(
     queued_message_count);
 }
 
-const RDMResponse *ResponderHelper::SetPersonality(
+RDMResponse *ResponderHelper::SetPersonality(
     const RDMRequest *request,
     PersonalityManager *personality_manager,
     uint16_t start_address,
@@ -223,7 +225,7 @@ const RDMResponse *ResponderHelper::SetPersonality(
   }
 }
 
-const RDMResponse *ResponderHelper::GetPersonalityDescription(
+RDMResponse *ResponderHelper::GetPersonalityDescription(
     const RDMRequest *request,
     const PersonalityManager *personality_manager,
     uint8_t queued_message_count) {
@@ -272,7 +274,7 @@ const RDMResponse *ResponderHelper::GetPersonalityDescription(
 /**
  * Get slot info
  */
-const RDMResponse *ResponderHelper::GetSlotInfo(
+RDMResponse *ResponderHelper::GetSlotInfo(
     const RDMRequest *request,
     const PersonalityManager *personality_manager,
     uint8_t queued_message_count) {
@@ -315,7 +317,7 @@ const RDMResponse *ResponderHelper::GetSlotInfo(
 /**
  * Get a slot description
  */
-const RDMResponse *ResponderHelper::GetSlotDescription(
+RDMResponse *ResponderHelper::GetSlotDescription(
     const RDMRequest *request,
     const PersonalityManager *personality_manager,
     uint8_t queued_message_count) {
@@ -365,7 +367,7 @@ const RDMResponse *ResponderHelper::GetSlotDescription(
 /**
  * Get slot default values
  */
-const RDMResponse *ResponderHelper::GetSlotDefaultValues(
+RDMResponse *ResponderHelper::GetSlotDefaultValues(
     const RDMRequest *request,
     const PersonalityManager *personality_manager,
     uint8_t queued_message_count) {
@@ -407,7 +409,7 @@ const RDMResponse *ResponderHelper::GetSlotDefaultValues(
 /**
  * Get the start address
  */
-const RDMResponse *ResponderHelper::GetDmxAddress(
+RDMResponse *ResponderHelper::GetDmxAddress(
     const RDMRequest *request,
     const PersonalityManager *personality_manager,
     uint16_t start_address,
@@ -422,7 +424,7 @@ const RDMResponse *ResponderHelper::GetDmxAddress(
 /**
  * Set the start address
  */
-const RDMResponse *ResponderHelper::SetDmxAddress(
+RDMResponse *ResponderHelper::SetDmxAddress(
     const RDMRequest *request,
     const PersonalityManager *personality_manager,
     uint16_t *dmx_address,
@@ -447,7 +449,7 @@ const RDMResponse *ResponderHelper::SetDmxAddress(
 /**
  * Get a sensor definition
  */
-const RDMResponse *ResponderHelper::GetSensorDefinition(
+RDMResponse *ResponderHelper::GetSensorDefinition(
     const RDMRequest *request, const Sensors &sensor_list) {
   uint8_t sensor_number;
   if (!ResponderHelper::ExtractUInt8(request, &sensor_number)) {
@@ -484,9 +486,9 @@ const RDMResponse *ResponderHelper::GetSensorDefinition(
   sensor_definition.normal_min = HostToNetwork(sensor->NormalMin());
   sensor_definition.normal_max = HostToNetwork(sensor->NormalMax());
   sensor_definition.recorded_support = sensor->RecordedSupportBitMask();
-  strncpy(sensor_definition.description, sensor->Description().c_str(),
-          sizeof(sensor_definition.description));
-
+  strings::CopyToFixedLengthBuffer(sensor->Description(),
+                                   sensor_definition.description,
+                                   arraysize(sensor_definition.description));
   return GetResponseFromData(
     request,
     reinterpret_cast<const uint8_t*>(&sensor_definition),
@@ -496,7 +498,7 @@ const RDMResponse *ResponderHelper::GetSensorDefinition(
 /**
  * Get a sensor value
  */
-const RDMResponse *ResponderHelper::GetSensorValue(
+RDMResponse *ResponderHelper::GetSensorValue(
     const RDMRequest *request, const Sensors &sensor_list) {
   uint8_t sensor_number;
   if (!ResponderHelper::ExtractUInt8(request, &sensor_number)) {
@@ -525,7 +527,7 @@ const RDMResponse *ResponderHelper::GetSensorValue(
 /**
  * Set a sensor value
  */
-const RDMResponse *ResponderHelper::SetSensorValue(
+RDMResponse *ResponderHelper::SetSensorValue(
     const RDMRequest *request, const Sensors &sensor_list) {
   uint8_t sensor_number;
   if (!ResponderHelper::ExtractUInt8(request, &sensor_number)) {
@@ -563,7 +565,7 @@ const RDMResponse *ResponderHelper::SetSensorValue(
 /**
  * Record a sensor
  */
-const RDMResponse *ResponderHelper::RecordSensor(
+RDMResponse *ResponderHelper::RecordSensor(
     const RDMRequest *request, const Sensors &sensor_list) {
   uint8_t sensor_number;
   if (!ResponderHelper::ExtractUInt8(request, &sensor_number)) {
@@ -588,7 +590,7 @@ const RDMResponse *ResponderHelper::RecordSensor(
 /**
  * Get the clock response.
  */
-const RDMResponse *ResponderHelper::GetRealTimeClock(
+RDMResponse *ResponderHelper::GetRealTimeClock(
     const RDMRequest *request,
     uint8_t queued_message_count) {
   if (request->ParamDataSize()) {
@@ -631,7 +633,7 @@ const RDMResponse *ResponderHelper::GetRealTimeClock(
       queued_message_count);
 }
 
-const RDMResponse *ResponderHelper::GetListInterfaces(
+RDMResponse *ResponderHelper::GetListInterfaces(
     const RDMRequest *request,
     const NetworkManagerInterface *network_manager,
     uint8_t queued_message_count) {
@@ -673,7 +675,7 @@ const RDMResponse *ResponderHelper::GetListInterfaces(
 }
 
 
-const RDMResponse *ResponderHelper::GetInterfaceLabel(
+RDMResponse *ResponderHelper::GetInterfaceLabel(
     const RDMRequest *request,
     const NetworkManagerInterface *network_manager,
     uint8_t queued_message_count) {
@@ -711,7 +713,7 @@ const RDMResponse *ResponderHelper::GetInterfaceLabel(
                              queued_message_count);
 }
 
-const RDMResponse *ResponderHelper::GetInterfaceHardwareAddressType1(
+RDMResponse *ResponderHelper::GetInterfaceHardwareAddressType1(
     const RDMRequest *request,
     const NetworkManagerInterface *network_manager,
     uint8_t queued_message_count) {
@@ -749,7 +751,7 @@ const RDMResponse *ResponderHelper::GetInterfaceHardwareAddressType1(
       queued_message_count);
 }
 
-const RDMResponse *ResponderHelper::GetIPV4CurrentAddress(
+RDMResponse *ResponderHelper::GetIPV4CurrentAddress(
     const RDMRequest *request,
     const NetworkManagerInterface *network_manager,
     uint8_t queued_message_count) {
@@ -797,24 +799,50 @@ const RDMResponse *ResponderHelper::GetIPV4CurrentAddress(
 }
 
 
-const RDMResponse *ResponderHelper::GetIPV4DefaultRoute(
+RDMResponse *ResponderHelper::GetIPV4DefaultRoute(
     const RDMRequest *request,
     const NetworkManagerInterface *network_manager,
     uint8_t queued_message_count) {
+  int32_t if_index = Interface::DEFAULT_INDEX;
   IPV4Address default_route;
-  if (!network_manager->GetIPV4DefaultRoute(&default_route)) {
+  if (!network_manager->GetIPV4DefaultRoute(&if_index, &default_route)) {
     return NackWithReason(request, NR_HARDWARE_FAULT);
   }
+
+  PACK(
+  struct ipv4_default_route_s {
+    uint32_t if_index;
+    uint32_t default_route;
+  });
+  STATIC_ASSERT(sizeof(ipv4_default_route_s) == 8);
+
+  struct ipv4_default_route_s ipv4_default_route;
+
+  if (if_index == Interface::DEFAULT_INDEX) {
+    // No default route interface index set, return special value
+    ipv4_default_route.if_index = HostToNetwork(NO_DEFAULT_ROUTE);
+  } else {
+    ipv4_default_route.if_index = HostToNetwork(if_index);
+  }
+
   if (default_route.IsWildcard()) {
     // No default route set, return special value
-    return GetUInt32Value(request, NO_DEFAULT_ROUTE, queued_message_count);
+    ipv4_default_route.default_route = HostToNetwork(NO_DEFAULT_ROUTE);
   } else {
-    return GetIPV4Address(request, default_route, queued_message_count);
+    // Already in correct byte order
+    ipv4_default_route.default_route = default_route.AsInt();
   }
+
+  return GetResponseFromData(
+      request,
+      reinterpret_cast<uint8_t*>(&ipv4_default_route),
+      sizeof(ipv4_default_route),
+      RDM_ACK,
+      queued_message_count);
 }
 
 
-const RDMResponse *ResponderHelper::GetDNSHostname(
+RDMResponse *ResponderHelper::GetDNSHostname(
     const RDMRequest *request,
     const NetworkManagerInterface *network_manager,
     uint8_t queued_message_count) {
@@ -831,7 +859,7 @@ const RDMResponse *ResponderHelper::GetDNSHostname(
 }
 
 
-const RDMResponse *ResponderHelper::GetDNSDomainName(
+RDMResponse *ResponderHelper::GetDNSDomainName(
     const RDMRequest *request,
     const NetworkManagerInterface *network_manager,
     uint8_t queued_message_count) {
@@ -847,7 +875,7 @@ const RDMResponse *ResponderHelper::GetDNSDomainName(
   }
 }
 
-const RDMResponse *ResponderHelper::GetDNSNameServer(
+RDMResponse *ResponderHelper::GetDNSNameServer(
     const RDMRequest *request,
     const NetworkManagerInterface *network_manager,
     uint8_t queued_message_count) {
@@ -886,7 +914,7 @@ const RDMResponse *ResponderHelper::GetDNSNameServer(
     queued_message_count);
 }
 
-const RDMResponse *ResponderHelper::GetParamDescription(
+RDMResponse *ResponderHelper::GetParamDescription(
     const RDMRequest *request,
     uint16_t pid,
     uint8_t pdl_size,
@@ -947,7 +975,7 @@ const RDMResponse *ResponderHelper::GetParamDescription(
       queued_message_count);
 }
 
-const RDMResponse *ResponderHelper::GetASCIIParamDescription(
+RDMResponse *ResponderHelper::GetASCIIParamDescription(
         const RDMRequest *request,
         uint16_t pid,
         rdm_command_class command_class,
@@ -968,7 +996,7 @@ const RDMResponse *ResponderHelper::GetASCIIParamDescription(
       queued_message_count);
 }
 
-const RDMResponse *ResponderHelper::GetBitFieldParamDescription(
+RDMResponse *ResponderHelper::GetBitFieldParamDescription(
         const RDMRequest *request,
         uint16_t pid,
         uint8_t pdl_size,
@@ -993,7 +1021,7 @@ const RDMResponse *ResponderHelper::GetBitFieldParamDescription(
 /*
  * Handle a request that returns an IPv4 address
  */
-const RDMResponse *ResponderHelper::GetIPV4Address(
+RDMResponse *ResponderHelper::GetIPV4Address(
     const RDMRequest *request,
     const IPV4Address &value,
     uint8_t queued_message_count) {
@@ -1008,7 +1036,7 @@ const RDMResponse *ResponderHelper::GetIPV4Address(
  * @brief Handle a request that returns a string
  * @note this truncates the string to max_length
  */
-const RDMResponse *ResponderHelper::GetString(
+RDMResponse *ResponderHelper::GetString(
     const RDMRequest *request,
     const string &value,
     uint8_t queued_message_count,
@@ -1027,7 +1055,7 @@ const RDMResponse *ResponderHelper::GetString(
       queued_message_count);
 }
 
-const RDMResponse *ResponderHelper::EmptyGetResponse(
+RDMResponse *ResponderHelper::EmptyGetResponse(
     const RDMRequest *request,
     uint8_t queued_message_count) {
   return GetResponseFromData(request,
@@ -1037,22 +1065,17 @@ const RDMResponse *ResponderHelper::EmptyGetResponse(
                              queued_message_count);
 }
 
-const RDMResponse *ResponderHelper::EmptySetResponse(
+RDMResponse *ResponderHelper::EmptySetResponse(
     const RDMRequest *request,
     uint8_t queued_message_count) {
-  return new RDMSetResponse(
-    request->DestinationUID(),
-    request->SourceUID(),
-    request->TransactionNumber(),
-    RDM_ACK,
-    queued_message_count,
-    request->SubDevice(),
-    request->ParamId(),
-    NULL,
-    0);
+  return GetResponseFromData(request,
+                             NULL,
+                             0,
+                             RDM_ACK,
+                             queued_message_count);
 }
 
-const RDMResponse *ResponderHelper::SetString(
+RDMResponse *ResponderHelper::SetString(
     const RDMRequest *request,
     string *value,
     uint8_t queued_message_count,
@@ -1066,7 +1089,7 @@ const RDMResponse *ResponderHelper::SetString(
   return EmptySetResponse(request, queued_message_count);
 }
 
-const RDMResponse *ResponderHelper::GetBoolValue(const RDMRequest *request,
+RDMResponse *ResponderHelper::GetBoolValue(const RDMRequest *request,
                                                  bool value,
                                                  uint8_t queued_message_count) {
   if (request->ParamDataSize()) {
@@ -1078,7 +1101,7 @@ const RDMResponse *ResponderHelper::GetBoolValue(const RDMRequest *request,
                              RDM_ACK, queued_message_count);
 }
 
-const RDMResponse *ResponderHelper::SetBoolValue(const RDMRequest *request,
+RDMResponse *ResponderHelper::SetBoolValue(const RDMRequest *request,
                                                  bool *value,
                                                  uint8_t queued_message_count) {
   uint8_t arg;
@@ -1095,7 +1118,7 @@ const RDMResponse *ResponderHelper::SetBoolValue(const RDMRequest *request,
 }
 
 template<typename T>
-static const RDMResponse *GenericGetIntValue(const RDMRequest *request,
+static RDMResponse *GenericGetIntValue(const RDMRequest *request,
                                              T value,
                                              uint8_t queued_message_count = 0) {
   if (request->ParamDataSize()) {
@@ -1110,21 +1133,21 @@ static const RDMResponse *GenericGetIntValue(const RDMRequest *request,
     queued_message_count);
 }
 
-const RDMResponse *ResponderHelper::GetUInt8Value(
+RDMResponse *ResponderHelper::GetUInt8Value(
     const RDMRequest *request,
     uint8_t value,
     uint8_t queued_message_count) {
   return GenericGetIntValue(request, value, queued_message_count);
 }
 
-const RDMResponse *ResponderHelper::GetUInt16Value(
+RDMResponse *ResponderHelper::GetUInt16Value(
     const RDMRequest *request,
     uint16_t value,
     uint8_t queued_message_count) {
   return GenericGetIntValue(request, value, queued_message_count);
 }
 
-const RDMResponse *ResponderHelper::GetUInt32Value(
+RDMResponse *ResponderHelper::GetUInt32Value(
     const RDMRequest *request,
     uint32_t value,
     uint8_t queued_message_count) {
@@ -1132,7 +1155,7 @@ const RDMResponse *ResponderHelper::GetUInt32Value(
 }
 
 template<typename T>
-static const RDMResponse *GenericSetIntValue(const RDMRequest *request,
+static RDMResponse *GenericSetIntValue(const RDMRequest *request,
                                              T *value,
                                              uint8_t queued_message_count = 0) {
   if (!GenericExtractValue(request, value)) {
@@ -1141,21 +1164,21 @@ static const RDMResponse *GenericSetIntValue(const RDMRequest *request,
   return ResponderHelper::EmptySetResponse(request, queued_message_count);
 }
 
-const RDMResponse *ResponderHelper::SetUInt8Value(
+RDMResponse *ResponderHelper::SetUInt8Value(
     const RDMRequest *request,
     uint8_t *value,
     uint8_t queued_message_count) {
   return GenericSetIntValue(request, value, queued_message_count);
 }
 
-const RDMResponse *ResponderHelper::SetUInt16Value(
+RDMResponse *ResponderHelper::SetUInt16Value(
     const RDMRequest *request,
     uint16_t *value,
     uint8_t queued_message_count) {
   return GenericSetIntValue(request, value, queued_message_count);
 }
 
-const RDMResponse *ResponderHelper::SetUInt32Value(
+RDMResponse *ResponderHelper::SetUInt32Value(
     const RDMRequest *request,
     uint32_t *value,
     uint8_t queued_message_count) {
