@@ -39,7 +39,7 @@ using std::string;
 using std::vector;
 
 void StringSplit(const string &input,
-                 vector<string> &tokens,  // NOLINT
+                 vector<string> *tokens,
                  const string &delimiters) {
   string::size_type start_offset = 0;
   string::size_type end_offset = 0;
@@ -47,12 +47,13 @@ void StringSplit(const string &input,
   while (1) {
     end_offset = input.find_first_of(delimiters, start_offset);
     if (end_offset == string::npos) {
-      tokens.push_back(input.substr(start_offset, input.size() - start_offset));
+      tokens->push_back(
+          input.substr(start_offset, input.size() - start_offset));
       return;
     }
-    tokens.push_back(input.substr(start_offset, end_offset - start_offset));
-    start_offset = end_offset + 1 > input.size() ? string::npos :
-                   end_offset + 1;
+    tokens->push_back(input.substr(start_offset, end_offset - start_offset));
+    start_offset = (end_offset + 1 > input.size()) ?
+                   string::npos : (end_offset + 1);
   }
 }
 
@@ -61,22 +62,23 @@ void StringTrim(string *input) {
   string::size_type start = input->find_first_not_of(characters_to_trim);
   string::size_type end = input->find_last_not_of(characters_to_trim);
 
-  if (start == string::npos)
+  if (start == string::npos) {
     input->clear();
-  else
+  } else {
     *input = input->substr(start, end - start + 1);
+  }
 }
 
 void ShortenString(string *input) {
   size_t index = input->find(static_cast<char>(0));
-  if (index != string::npos)
+  if (index != string::npos) {
     input->erase(index);
+  }
 }
 
 bool StringBeginsWith(const string &s, const string &prefix) {
   if (s.length() >= prefix.length()) {
-    return
-      0 == s.compare(0, prefix.length(), prefix);
+    return (0 == s.compare(0, prefix.length(), prefix));
   } else {
     return false;
   }
@@ -109,23 +111,11 @@ bool StripSuffix(string *s, const string &suffix) {
   }
 }
 
-string IntToString(int i) {
-  ostringstream str;
-  str << i;
-  return str.str();
-}
-
-string IntToString(unsigned int i) {
-  ostringstream str;
-  str << i;
-  return str.str();
-}
-
 string IntToHexString(unsigned int i, unsigned int width) {
+  strings::_ToHex<unsigned int> v = strings::_ToHex<unsigned int>(
+      i, static_cast<int>(width), true);
   ostringstream str;
-  // In C++, you only get the 0x on non-zero values, so we have to explicitly
-  // add it for all values
-  str << "0x" << std::setw(width) << std::hex << std::setfill('0') << i;
+  str << v;
   return str.str();
 }
 
@@ -162,77 +152,95 @@ bool StringToBoolTolerant(const string &value, bool *output) {
 }
 
 bool StringToInt(const string &value, unsigned int *output, bool strict) {
-  if (value.empty())
+  if (value.empty()) {
     return false;
+  }
   char *end_ptr;
   errno = 0;
   long long l = strtoll(value.data(), &end_ptr, 10);  // NOLINT(runtime/int)
-  if (l < 0 || (l == 0 && errno != 0))
+  if (l < 0 || (l == 0 && errno != 0)) {
     return false;
-  if (value == end_ptr)
+  }
+  if (value == end_ptr) {
     return false;
-  if (strict && *end_ptr != 0)
+  }
+  if (strict && *end_ptr != 0) {
     return false;
-  if (l > static_cast<long long>(UINT32_MAX))  // NOLINT(runtime/int)
+  }
+  if (l > static_cast<long long>(UINT32_MAX)) {  // NOLINT(runtime/int)
     return false;
+  }
   *output = static_cast<unsigned int>(l);
   return true;
 }
 
 bool StringToInt(const string &value, uint16_t *output, bool strict) {
   unsigned int v;
-  if (!StringToInt(value, &v, strict))
+  if (!StringToInt(value, &v, strict)) {
     return false;
-  if (v > UINT16_MAX)
+  }
+  if (v > UINT16_MAX) {
     return false;
+  }
   *output = static_cast<uint16_t>(v);
   return true;
 }
 
 bool StringToInt(const string &value, uint8_t *output, bool strict) {
   unsigned int v;
-  if (!StringToInt(value, &v, strict))
+  if (!StringToInt(value, &v, strict)) {
     return false;
-  if (v > UINT8_MAX)
+  }
+  if (v > UINT8_MAX) {
     return false;
+  }
   *output = static_cast<uint8_t>(v);
   return true;
 }
 
 bool StringToInt(const string &value, int *output, bool strict) {
-  if (value.empty())
+  if (value.empty()) {
     return false;
+  }
   char *end_ptr;
   errno = 0;
   long long l = strtoll(value.data(), &end_ptr, 10);  // NOLINT(runtime/int)
-  if (l == 0 && errno != 0)
+  if (l == 0 && errno != 0) {
     return false;
-  if (value == end_ptr)
+  }
+  if (value == end_ptr) {
     return false;
-  if (strict && *end_ptr != 0)
+  }
+  if (strict && *end_ptr != 0) {
     return false;
-  if (l < INT32_MIN || l > INT32_MAX)
+  }
+  if (l < INT32_MIN || l > INT32_MAX) {
     return false;
+  }
   *output = static_cast<unsigned int>(l);
   return true;
 }
 
 bool StringToInt(const string &value, int16_t *output, bool strict) {
   int v;
-  if (!StringToInt(value, &v, strict))
+  if (!StringToInt(value, &v, strict)) {
     return false;
-  if (v < INT16_MIN || v > INT16_MAX)
+  }
+  if (v < INT16_MIN || v > INT16_MAX) {
     return false;
+  }
   *output = static_cast<int16_t>(v);
   return true;
 }
 
 bool StringToInt(const string &value, int8_t *output, bool strict) {
   int v;
-  if (!StringToInt(value, &v, strict))
+  if (!StringToInt(value, &v, strict)) {
     return false;
-  if (v < INT8_MIN || v > INT8_MAX)
+  }
+  if (v < INT8_MIN || v > INT8_MAX) {
     return false;
+  }
   *output = static_cast<int8_t>(v);
   return true;
 }
@@ -298,19 +306,17 @@ string EncodeString(const string &original) {
     if (isprint(*iter)) {
       encoded << *iter;
     } else {
-      encoded << "\\x" << std::setfill('0') << std::setw(2) << std::hex <<
-          static_cast<unsigned int>(*iter);
+      encoded << "\\x"
+              << ola::strings::ToHex(static_cast<uint8_t>(*iter), false);
     }
   }
   return encoded.str();
 }
 
 void ReplaceAll(string *original, const string &find, const string &replace) {
-  if (original->empty())
-    return;  // No text, so nothing to do
-
-  if (find.empty())
-    return;  // Nothing to find, so nothing to do
+  if (original->empty() || find.empty()) {
+    return;  // No text or nothing to find, so nothing to do
+  }
 
   size_t start = 0;
   while ((start = original->find(find, start)) != string::npos) {
@@ -322,74 +328,86 @@ void ReplaceAll(string *original, const string &find, const string &replace) {
 
 bool HexStringToInt(const string &value, uint8_t *output) {
   uint32_t temp;
-  if (!HexStringToInt(value, &temp))
+  if (!HexStringToInt(value, &temp)) {
     return false;
-  if (temp > 0xff)
+  }
+  if (temp > UINT8_MAX) {
     return false;
+  }
   *output = static_cast<uint8_t>(temp);
   return true;
 }
 
 bool HexStringToInt(const string &value, uint16_t *output) {
   uint32_t temp;
-  if (!HexStringToInt(value, &temp))
+  if (!HexStringToInt(value, &temp)) {
     return false;
-  if (temp > UINT16_MAX)
+  }
+  if (temp > UINT16_MAX) {
     return false;
+  }
   *output = static_cast<uint16_t>(temp);
   return true;
 }
 
 bool HexStringToInt(const string &value, uint32_t *output) {
-  if (value.empty())
+  if (value.empty()) {
     return false;
+  }
 
   size_t found = value.find_first_not_of("ABCDEFabcdef0123456789");
-  if (found != string::npos)
+  if (found != string::npos) {
     return false;
+  }
   *output = strtoul(value.data(), NULL, 16);
   return true;
 }
 
 bool HexStringToInt(const string &value, int8_t *output) {
   int32_t temp;
-  if (!HexStringToInt(value, &temp))
+  if (!HexStringToInt(value, &temp)) {
     return false;
-  if (temp < 0 || temp > static_cast<int32_t>(UINT8_MAX))
+  }
+  if (temp < 0 || temp > static_cast<int32_t>(UINT8_MAX)) {
     return false;
+  }
   *output = static_cast<int8_t>(temp);
   return true;
 }
 
 bool HexStringToInt(const string &value, int16_t *output) {
   int32_t temp;
-  if (!HexStringToInt(value, &temp))
+  if (!HexStringToInt(value, &temp)) {
     return false;
-  if (temp < 0 || temp > static_cast<int32_t>(UINT16_MAX))
+  }
+  if (temp < 0 || temp > static_cast<int32_t>(UINT16_MAX)) {
     return false;
+  }
   *output = static_cast<int16_t>(temp);
   return true;
 }
 
 bool HexStringToInt(const string &value, int32_t *output) {
-  if (value.empty())
+  if (value.empty()) {
     return false;
+  }
 
   size_t found = value.find_first_not_of("ABCDEFabcdef0123456789");
-  if (found != string::npos)
+  if (found != string::npos) {
     return false;
+  }
   *output = strtoll(value.data(), NULL, 16);
   return true;
 }
 
 void ToLower(string *s) {
   std::transform(s->begin(), s->end(), s->begin(),
-      std::ptr_fun<int, int>(std::tolower));
+                 std::ptr_fun<int, int>(std::tolower));
 }
 
 void ToUpper(string *s) {
   std::transform(s->begin(), s->end(), s->begin(),
-      std::ptr_fun<int, int>(std::toupper));
+                 std::ptr_fun<int, int>(std::toupper));
 }
 
 void CapitalizeLabel(string *s) {
@@ -397,14 +415,17 @@ void CapitalizeLabel(string *s) {
   for (string::iterator iter = s->begin(); iter != s->end(); ++iter) {
     switch (*iter) {
       case '-':
+        // fall through, also convert to space then capitalize next character
       case '_':
         *iter = ' ';
+        // fall through, also convert to space then capitalize next character
       case ' ':
         capitalize = true;
         break;
       default:
-        if (capitalize && islower(*iter))
+        if (capitalize && islower(*iter)) {
           *iter = toupper(*iter);
+        }
         capitalize = false;
     }
   }
@@ -431,8 +452,9 @@ void CustomCapitalizeLabel(string *s) {
 
     while (true) {
       size_t match_position = s->find(ancronym, last_match);
-      if (match_position == string::npos)
+      if (match_position == string::npos) {
         break;
+      }
       last_match = match_position + 1;
       size_t end_position = match_position + ancronym_size;
 
@@ -449,32 +471,4 @@ void CustomCapitalizeLabel(string *s) {
 
   CapitalizeLabel(s);
 }
-
-void FormatData(std::ostream *out,
-                const uint8_t *data,
-                unsigned int length,
-                unsigned int indent,
-                unsigned int byte_per_line) {
-  ostringstream raw, ascii;
-  raw << std::setw(2) << std::hex;
-  for (unsigned int i = 0; i != length; i++) {
-    raw << std::setfill('0') << std::setw(2) <<
-        static_cast<unsigned int>(data[i]) << " ";
-    if (isprint(data[i]))
-      ascii << data[i];
-    else
-      ascii << ".";
-
-    if (i % byte_per_line == byte_per_line - 1) {
-      *out << string(indent, ' ') << raw.str() << " " << ascii.str() << endl;
-      raw.str("");
-      ascii.str("");
-    }
-  }
-  if (length % byte_per_line != 0) {
-    // pad if needed
-    raw << string(3 * (byte_per_line - (length % byte_per_line)), ' ');
-    *out << string(indent, ' ') << raw.str() << " " << ascii.str() << endl;
-  }
-}
 }  // namespace ola
