@@ -22,6 +22,7 @@
 #define INCLUDE_OLA_CLIENT_CLIENTTYPES_H_
 
 #include <ola/dmx/SourcePriorities.h>
+#include <ola/rdm/RDMFrame.h>
 #include <ola/rdm/RDMResponseCodes.h>
 
 #include <olad/PortConstants.h>
@@ -42,10 +43,14 @@ namespace client {
  */
 class OlaPlugin {
  public:
-  OlaPlugin(unsigned int id, const std::string &name, bool active)
+  OlaPlugin(unsigned int id,
+            const std::string &name,
+            bool active,
+            bool enabled)
       : m_id(id),
         m_name(name),
-        m_active(active) {}
+        m_active(active),
+        m_enabled(enabled) {}
   ~OlaPlugin() {}
 
   /**
@@ -64,6 +69,12 @@ class OlaPlugin {
    */
   bool IsActive() const { return m_active; }
 
+  /**
+   * @brief Indicates if the plugin is enabled or not
+   * @return true if the plugin is enabled, false otherwise.
+   */
+  bool IsEnabled() const { return m_enabled; }
+
   bool operator<(const OlaPlugin &other) const {
     return m_id < other.m_id;
   }
@@ -72,6 +83,7 @@ class OlaPlugin {
   unsigned int m_id;  // id of this plugin
   std::string m_name;  // plugin name
   bool m_active;
+  bool m_enabled;
 };
 
 /**
@@ -259,30 +271,37 @@ class OlaUniverse {
   OlaUniverse(unsigned int id,
               merge_mode m,
               const std::string &name,
-              unsigned int input_port_count,
-              unsigned int output_port_count,
+              const std::vector<OlaInputPort> &input_ports,
+              const std::vector<OlaOutputPort> &output_ports,
               unsigned int rdm_device_count):
     m_id(id),
     m_merge_mode(m),
     m_name(name),
-    m_input_port_count(input_port_count),
-    m_output_port_count(output_port_count),
+    m_input_ports(input_ports),
+    m_output_ports(output_ports),
     m_rdm_device_count(rdm_device_count) {}
   ~OlaUniverse() {}
 
   unsigned int Id() const { return m_id;}
   merge_mode MergeMode() const { return m_merge_mode; }
   const std::string& Name() const { return m_name;}
-  unsigned int InputPortCount() const { return m_input_port_count; }
-  unsigned int OutputPortCount() const { return m_output_port_count; }
+  unsigned int InputPortCount() const { return m_input_ports.size(); }
+  unsigned int OutputPortCount() const { return m_output_ports.size(); }
   unsigned int RDMDeviceCount() const { return m_rdm_device_count; }
 
+  const std::vector<OlaInputPort> &InputPorts() const {
+    return m_input_ports;
+  }
+  const std::vector<OlaOutputPort> &OutputPorts() const {
+    return m_output_ports;
+  }
+
  private:
   unsigned int m_id;
   merge_mode m_merge_mode;
   std::string m_name;
-  unsigned int m_input_port_count;
-  unsigned int m_output_port_count;
+  std::vector<OlaInputPort> m_input_ports;
+  std::vector<OlaOutputPort> m_output_ports;
   unsigned int m_rdm_device_count;
 };
 
@@ -316,6 +335,11 @@ struct RDMMetadata {
    */
   ola::rdm::rdm_response_code response_code;
 
+  /**
+   * @brief The RDMFrames that made up this response.
+   */
+  std::vector<ola::rdm::RDMFrame> frames;
+
   /**
    * @brief Construct a new RDMMetadata object.
    * The default response code is RDM_FAILED_TO_SEND.
