@@ -34,7 +34,7 @@
 #include <stdlib.h>
 #ifdef _WIN32
 #define WIN32_LEAN_AND_MEAN
-#include <Winsock2.h>
+#include <ola/win/CleanWinSock2.h>
 #else
 #include <sys/select.h>
 #include <sys/socket.h>
@@ -190,7 +190,7 @@ class HTTPServer: public ola::thread::Thread {
   const std::string DataDir() const { return m_data_dir; }
 
   // Return an error
-  int ServeError(HTTPResponse *response, const std::string &details="");
+  int ServeError(HTTPResponse *response, const std::string &details = "");
   int ServeNotFound(HTTPResponse *response);
   static int ServeRedirect(HTTPResponse *response, const std::string &location);
 
@@ -205,9 +205,10 @@ class HTTPServer: public ola::thread::Thread {
   static const char CONTENT_TYPE_PNG[];
   static const char CONTENT_TYPE_CSS[];
   static const char CONTENT_TYPE_JS[];
+  static const char CONTENT_TYPE_OCT[];
 
   // Expose the SelectServer
-  ola::io::SelectServer *SelectServer() { return &m_select_server; }
+  ola::io::SelectServer *SelectServer() { return m_select_server.get(); }
 
  private :
   typedef struct {
@@ -237,7 +238,7 @@ class HTTPServer: public ola::thread::Thread {
   typedef std::set<DescriptorState*, Descriptor_lt> SocketSet;
 
   struct MHD_Daemon *m_httpd;
-  ola::io::SelectServer m_select_server;
+  std::auto_ptr<ola::io::SelectServer> m_select_server;
   SocketSet m_sockets;
 
   std::map<std::string, BaseHTTPCallback*> m_handlers;
