@@ -11,7 +11,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  *
  * KiNetPlugin.cpp
  * The KiNET plugin for ola
@@ -32,9 +32,7 @@ namespace kinet {
 
 class KiNetPlugin : public Plugin {
  public:
-    explicit KiNetPlugin(PluginAdaptor *plugin_adaptor):
-      Plugin(plugin_adaptor) {}
-
+    explicit KiNetPlugin(PluginAdaptor *plugin_adaptor);
     ~KiNetPlugin();
 
     std::string Name() const { return PLUGIN_NAME; }
