@@ -27,12 +27,14 @@
 #include "ola/Callback.h"
 #include "ola/Constants.h"
 #include "ola/Logging.h"
+#include "ola/io/ByteString.h"
 #include "ola/rdm/RDMCommand.h"
 #include "ola/rdm/RDMCommandSerializer.h"
 #include "ola/rdm/RDMEnums.h"
 #include "ola/rdm/UID.h"
 #include "ola/rdm/UIDSet.h"
 #include "ola/stl/STLUtils.h"
+#include "ola/strings/Format.h"
 #include "plugins/usbpro/BaseUsbProWidget.h"
 #include "plugins/usbpro/EnttecUsbProWidget.h"
 #include "plugins/usbpro/EnttecUsbProWidgetImpl.h"
@@ -41,13 +43,16 @@ namespace ola {
 namespace plugin {
 namespace usbpro {
 
+using ola::io::ByteString;
 using ola::rdm::RDMCommand;
 using ola::rdm::RDMCommandSerializer;
-using ola::rdm::RDMRequest;
+using ola::rdm::RDMReply;
+using ola::rdm::RunRDMCallback;
 using ola::rdm::RDMRequest;
 using ola::rdm::RDMResponse;
 using ola::rdm::UID;
 using ola::rdm::UIDSet;
+using ola::strings::ToHex;
 using std::auto_ptr;
 using std::string;
 using std::vector;
@@ -91,7 +96,8 @@ EnttecPortImpl::EnttecPortImpl(const OperationLabels &ops, const UID &uid,
     : m_send_cb(send_cb),
       m_ops(ops),
       m_active(true),
-      m_dmx_callback(NULL),
+      m_watchdog(WATCHDOG_LIMIT,
+                 NewCallback(this, &EnttecPortImpl::WatchdogFired)),
       m_discovery_agent(this),
       m_uid(uid),
       m_transaction_number(0),
@@ -107,10 +113,7 @@ EnttecPortImpl::EnttecPortImpl(const OperationLabels &ops, const UID &uid,
 void EnttecPortImpl::Stop() {
   m_active = false;
 
-  if (m_dmx_callback) {
-    delete m_dmx_callback;
-    m_dmx_callback = NULL;
-  }
+  m_dmx_callback.reset();
 
   // empty params struct
   usb_pro_parameters params;
@@ -147,9 +150,7 @@ bool EnttecPortImpl::SendDMX(const DmxBuffer &buffer) {
  * Set the callback to run when new DMX data arrives
  */
 void EnttecPortImpl::SetDMXCallback(ola::Callback0<void> *callback) {
-  if (m_dmx_callback)
-    delete m_dmx_callback;
-  m_dmx_callback = callback;
+  m_dmx_callback.reset(callback);
 }
 
 /*
@@ -157,13 +158,15 @@ void EnttecPortImpl::SetDMXCallback(ola::Callback0<void> *callback) {
  * @return true on success, false on failure
  */
 bool EnttecPortImpl::ChangeToReceiveMode(bool change_only) {
-  if (!m_active)
+  if (!m_active) {
     return false;
+  }
 
   uint8_t mode = change_only;
   bool status = m_send_cb->Run(m_ops.change_to_rx_mode, &mode, sizeof(mode));
-  if (status && change_only)
+  if (status && change_only) {
     m_input_buffer.Blackout();
+  }
   return status;
 }
 
@@ -215,8 +218,9 @@ bool EnttecPortImpl::SetParameters(uint8_t break_time,
       reinterpret_cast<uint8_t*>(&widget_parameters),
       sizeof(widget_parameters));
 
-  if (!ret)
+  if (!ret) {
     OLA_WARN << "Failed to send a set params message";
+  }
   return ret;
 }
 
@@ -224,51 +228,31 @@ bool EnttecPortImpl::SetParameters(uint8_t break_time,
 /**
  * Send an RDM Request.
  */
-void EnttecPortImpl::SendRDMRequest(
-    const ola::rdm::RDMRequest *request,
-    ola::rdm::RDMCallback *on_complete) {
-  auto_ptr<const ola::rdm::RDMRequest> request_ptr(request);
-  vector<string> packets;
+void EnttecPortImpl::SendRDMRequest(RDMRequest *request_ptr,
+                                    ola::rdm::RDMCallback *on_complete) {
+  auto_ptr<RDMRequest> request(request_ptr);
+
   if (m_rdm_request_callback) {
     OLA_WARN << "Previous request hasn't completed yet, dropping request";
-    on_complete->Run(ola::rdm::RDM_FAILED_TO_SEND, NULL, packets);
+    RunRDMCallback(on_complete, ola::rdm::RDM_FAILED_TO_SEND);
     return;
   }
 
-  // Prepare the buffer for the RDM data including the start code.
-  unsigned int rdm_size = RDMCommandSerializer::RequiredSize(*request);
-  uint8_t *data = new uint8_t[rdm_size + 1];
-  data[0] = RDMCommand::START_CODE;
-
-  unsigned int this_transaction_number = m_transaction_number++;
-  unsigned int port_id = 1;
-
-  bool r = RDMCommandSerializer::Pack(*request, &data[1], &rdm_size, m_uid,
-                                      this_transaction_number, port_id);
-
-  if (!r) {
-    OLA_WARN << "Failed to pack message, dropping request";
-    delete[] data;
-    on_complete->Run(ola::rdm::RDM_FAILED_TO_SEND, NULL, packets);
-    return;
-  }
+  request->SetSourceUID(m_uid);
+  request->SetTransactionNumber(m_transaction_number++);
+  request->SetPortId(PORT_ID);
 
+  m_pending_request.reset(request.release());
   m_rdm_request_callback = on_complete;
-  // re-write the request so it appears to originate from this widget.
-  m_pending_request = request->DuplicateWithControllerParams(
-      m_uid,
-      this_transaction_number,
-      port_id);
 
-  const uint8_t label = (
-      IsDUBRequest(request) ? m_ops.rdm_discovery : m_ops.send_rdm);
-  bool ok = m_send_cb->Run(label, data, rdm_size + 1);
-  delete[] data;
+  bool ok = PackAndSendRDMRequest(
+      m_pending_request->IsDUB() ? m_ops.rdm_discovery : m_ops.send_rdm,
+      m_pending_request.get());
 
   if (!ok) {
+    m_pending_request.reset();
     m_rdm_request_callback = NULL;
-    m_pending_request = NULL;
-    on_complete->Run(ola::rdm::RDM_FAILED_TO_SEND, NULL, packets);
+    RunRDMCallback(on_complete, ola::rdm::RDM_FAILED_TO_SEND);
   }
 }
 
@@ -303,13 +287,15 @@ void EnttecPortImpl::RunIncrementalDiscovery(
  */
 void EnttecPortImpl::MuteDevice(const ola::rdm::UID &target,
                                 MuteDeviceCallback *mute_complete) {
+  OLA_INFO << "Muting " << target << ", TN: "
+           << static_cast<int>(m_transaction_number);
   auto_ptr<RDMRequest> mute_request(
       ola::rdm::NewMuteRequest(m_uid, target, m_transaction_number++));
-  OLA_INFO << "Muting " << target;
-  if (PackAndSendRDMRequest(m_ops.send_rdm, mute_request.get()))
+  if (PackAndSendRDMRequest(m_ops.send_rdm, mute_request.get())) {
     m_mute_callback = mute_complete;
-  else
+  } else {
     mute_complete->Run(false);
+  }
 }
 
 
@@ -319,10 +305,11 @@ void EnttecPortImpl::MuteDevice(const ola::rdm::UID &target,
  * completes.
  */
 void EnttecPortImpl::UnMuteAll(UnMuteDeviceCallback *unmute_complete) {
+  OLA_INFO << "Un-muting all devices, TN: "
+           << static_cast<int>(m_transaction_number);
   auto_ptr<RDMRequest> unmute_request(
       ola::rdm::NewUnMuteRequest(m_uid, ola::rdm::UID::AllDevices(),
                                  m_transaction_number++));
-  OLA_INFO << "Un-muting all devices";
   if (PackAndSendRDMRequest(m_ops.send_rdm, unmute_request.get())) {
     m_unmute_callback = unmute_complete;
   } else {
@@ -342,10 +329,11 @@ void EnttecPortImpl::Branch(const ola::rdm::UID &lower,
       ola::rdm::NewDiscoveryUniqueBranchRequest(m_uid, lower, upper,
                                                 m_transaction_number++));
   OLA_INFO << "Sending DUB packet: " << lower << " - " << upper;
-  if (PackAndSendRDMRequest(m_ops.rdm_discovery, branch_request.get()))
+  if (PackAndSendRDMRequest(m_ops.rdm_discovery, branch_request.get())) {
     m_branch_callback = callback;
-  else
+  } else {
     callback->Run(NULL, 0);
+  }
 }
 
 
@@ -363,8 +351,11 @@ void EnttecPortImpl::Branch(const ola::rdm::UID &lower,
  * The length of this message should be 0.
  */
 void EnttecPortImpl::HandleRDMTimeout(unsigned int length) {
-  if (length)
+  if (length) {
     OLA_WARN << "Strange RDM timeout message, length was " << length;
+  }
+
+  m_watchdog.Disable();
 
   // check what operation we were waiting on
   if (m_unmute_callback) {
@@ -385,22 +376,21 @@ void EnttecPortImpl::HandleRDMTimeout(unsigned int length) {
       m_discovery_response = NULL;
       m_discovery_response_size = 0;
     }
-  } else if (m_rdm_request_callback && m_pending_request) {
-    ola::rdm::rdm_response_code code;
-    if (IsDUBRequest(m_pending_request))
-        code = ola::rdm::RDM_TIMEOUT;
-    else
-      code = (
+  } else if (m_rdm_request_callback && m_pending_request.get()) {
+    ola::rdm::RDMStatusCode status_code;
+    if (m_pending_request->IsDUB()) {
+        status_code = ola::rdm::RDM_TIMEOUT;
+    } else {
+      status_code = (
           m_pending_request->DestinationUID().IsBroadcast() ?
           ola::rdm::RDM_WAS_BROADCAST :
           ola::rdm::RDM_TIMEOUT);
+    }
 
     ola::rdm::RDMCallback *callback = m_rdm_request_callback;
     m_rdm_request_callback = NULL;
-    delete m_pending_request;
-    m_pending_request = NULL;
-    vector<string> packets;
-    callback->Run(code, NULL, packets);
+    m_pending_request.reset();
+    RunRDMCallback(callback, status_code);
   }
 }
 
@@ -410,20 +400,13 @@ void EnttecPortImpl::HandleRDMTimeout(unsigned int length) {
  */
 void EnttecPortImpl::HandleParameters(const uint8_t *data,
                                       unsigned int length) {
-  if (m_outstanding_param_callbacks.empty())
+  if (m_outstanding_param_callbacks.empty()) {
     return;
+  }
 
-  // parameters
-  typedef struct {
-    uint8_t firmware;
-    uint8_t firmware_high;
-    uint8_t break_time;
-    uint8_t mab_time;
-    uint8_t rate;
-  } widget_parameters_reply;
-
-  if (length < sizeof(usb_pro_parameters))
+  if (length < sizeof(usb_pro_parameters)) {
     return;
+  }
 
   usb_pro_parameters params;
   memcpy(&params, data, sizeof(usb_pro_parameters));
@@ -448,12 +431,12 @@ void EnttecPortImpl::HandleIncomingDataMessage(const uint8_t *data,
                                                unsigned int length) {
   bool waiting_for_dub_response = (
       m_branch_callback != NULL || (
-      (m_rdm_request_callback && IsDUBRequest(m_pending_request))));
+      (m_rdm_request_callback && m_pending_request->IsDUB())));
 
   // if we're not waiting for a DUB response, and this isn't an RDM frame, then
   // let the super class handle it.
   if (!waiting_for_dub_response && length >= 2 &&
-      data[1] != ola::rdm::RDMCommand::START_CODE) {
+      data[1] != ola::rdm::START_CODE) {
     HandleDMX(data, length);
     return;
   }
@@ -466,6 +449,8 @@ void EnttecPortImpl::HandleIncomingDataMessage(const uint8_t *data,
     return;
   }
 
+  m_watchdog.Disable();
+
   // skip over the status bit
   data++;
   length--;
@@ -474,8 +459,8 @@ void EnttecPortImpl::HandleIncomingDataMessage(const uint8_t *data,
     // discovery responses are *always* followed by the timeout message and
     // it's important that we wait for this before sending the next command
     if (m_discovery_response) {
-      OLA_WARN <<
-        "multiple discovery responses received, ignoring all but the first.";
+      OLA_WARN << "Multiple discovery responses received, ignoring all but "
+                  "the first.";
       return;
     }
     uint8_t *response_data = new uint8_t[length];
@@ -492,28 +477,15 @@ void EnttecPortImpl::HandleIncomingDataMessage(const uint8_t *data,
   } else if (m_rdm_request_callback) {
     ola::rdm::RDMCallback *callback = m_rdm_request_callback;
     m_rdm_request_callback = NULL;
-    const ola::rdm::RDMRequest *request = m_pending_request;
-    m_pending_request = NULL;
-
-    vector<string> packets;
-    ola::rdm::rdm_response_code response_code;
-    ola::rdm::RDMResponse *response = NULL;
-
+    auto_ptr<const ola::rdm::RDMRequest> request(m_pending_request.release());
+    auto_ptr<RDMReply> reply;
     if (waiting_for_dub_response) {
-      response_code = ola::rdm::RDM_DUB_RESPONSE;
-      packets.push_back(
-          string(reinterpret_cast<const char*>(data), length));
+      reply.reset(RDMReply::DUBReply(rdm::RDMFrame(data, length)));
     } else {
-      // try to inflate
-      string packet(reinterpret_cast<const char*>(data + 1), length - 1);
-      packets.push_back(packet);
-      response = ola::rdm::RDMResponse::InflateFromData(
-          packet,
-          &response_code,
-          request);
+      reply.reset(RDMReply::FromFrame(rdm::RDMFrame(data, length),
+                                      request.get()));
     }
-    callback->Run(response_code, response, packets);
-    delete request;
+    callback->Run(reply.get());
   }
 }
 
@@ -534,7 +506,7 @@ void EnttecPortImpl::HandleDMXDiff(const uint8_t *data, unsigned int length) {
   }
 
   const widget_data_changed *widget_reply =
-    reinterpret_cast<const widget_data_changed*>(data);
+      reinterpret_cast<const widget_data_changed*>(data);
 
   unsigned int start_channel = widget_reply->start * 8;
   unsigned int offset = 0;
@@ -543,12 +515,14 @@ void EnttecPortImpl::HandleDMXDiff(const uint8_t *data, unsigned int length) {
   // doesn't seem to provide a guarantee on the ordering of packets. Packets
   // with non-0 start codes are almost certainly going to cause problems.
   if (start_channel == 0 && (widget_reply->changed[0] & 0x01) &&
-      widget_reply->data[offset])
+      widget_reply->data[offset]) {
     return;
+  }
 
   for (int i = 0; i < 40; i++) {
-    if (start_channel + i > DMX_UNIVERSE_SIZE + 1 || offset + 6 >= length)
+    if (start_channel + i > DMX_UNIVERSE_SIZE + 1 || offset + 6 >= length) {
       break;
+    }
 
     if (widget_reply->changed[i/8] & (1 << (i % 8)) && start_channel + i != 0) {
       m_input_buffer.SetChannel(start_channel + i - 1,
@@ -557,8 +531,9 @@ void EnttecPortImpl::HandleDMXDiff(const uint8_t *data, unsigned int length) {
     }
   }
 
-  if (m_dmx_callback)
+  if (m_dmx_callback.get()) {
     m_dmx_callback->Run();
+  }
 }
 
 
@@ -572,22 +547,24 @@ void EnttecPortImpl::HandleDMX(const uint8_t *data,
     uint8_t dmx[DMX_UNIVERSE_SIZE + 1];
   } widget_dmx;
 
-  if (length < 2)
+  if (length < 2) {
     return;
+  }
 
   const widget_dmx *widget_reply = reinterpret_cast<const widget_dmx*>(data);
 
   if (widget_reply->status) {
-    OLA_WARN << "UsbPro got corrupted packet, status: " <<
-      static_cast<int>(widget_reply->status);
+    OLA_WARN << "UsbPro got corrupted packet, status: "
+             << static_cast<int>(widget_reply->status);
     return;
   }
 
   // only handle start code = 0
   if (length > 2 && widget_reply->dmx[0] == 0) {
     m_input_buffer.Set(widget_reply->dmx + 1, length - 2);
-    if (m_dmx_callback)
+    if (m_dmx_callback.get()) {
       m_dmx_callback->Run();
+    }
   }
   return;
 }
@@ -604,8 +581,9 @@ void EnttecPortImpl::DiscoveryComplete(ola::rdm::RDMDiscoveryCallback *callback,
                                        bool,
                                        const UIDSet &uids) {
   OLA_DEBUG << "Enttec Pro discovery complete: " << uids;
-  if (callback)
+  if (callback) {
     callback->Run(uids);
+  }
 }
 
 
@@ -614,20 +592,25 @@ void EnttecPortImpl::DiscoveryComplete(ola::rdm::RDMDiscoveryCallback *callback,
  */
 bool EnttecPortImpl::PackAndSendRDMRequest(uint8_t label,
                                            const RDMRequest *request) {
-  unsigned int rdm_length = RDMCommandSerializer::RequiredSize(*request);
-  uint8_t data[rdm_length + 1];  // inc start code
-  data[0] = RDMCommand::START_CODE;
-  RDMCommandSerializer::Pack(*request, &data[1], &rdm_length);
-  return m_send_cb->Run(label, data, rdm_length + 1);
+  ByteString data;
+  if (!RDMCommandSerializer::PackWithStartCode(*request, &data)) {
+    return false;
+  }
+
+  bool ok = m_send_cb->Run(label, data.data(), data.size());
+  if (ok) {
+    m_watchdog.Enable();
+  }
+  return ok;
 }
 
+void EnttecPortImpl::ClockWatchdog() {
+  m_watchdog.Clock();
+}
 
-/**
- * Return true if this is a Discovery Unique Branch request
- */
-bool EnttecPortImpl::IsDUBRequest(const ola::rdm::RDMRequest *request) {
-  return (request->CommandClass() == ola::rdm::RDMCommand::DISCOVER_COMMAND &&
-          request->ParamId() == ola::rdm::PID_DISC_UNIQUE_BRANCH);
+void EnttecPortImpl::WatchdogFired() {
+  OLA_WARN << "Enttec watchdog fired";
+  // TODO(simon): think about what we want to do here.
 }
 
 
@@ -671,13 +654,12 @@ bool EnttecPort::SetParameters(uint8_t break_time, uint8_t mab_time,
   return m_impl->SetParameters(break_time, mab_time, rate);
 }
 
-void EnttecPort::SendRDMRequest(const ola::rdm::RDMRequest *request,
+void EnttecPort::SendRDMRequest(ola::rdm::RDMRequest *request,
                                 ola::rdm::RDMCallback *on_complete) {
   if (m_enable_rdm) {
     m_controller->SendRDMRequest(request, on_complete);
   } else {
-    vector<string> packets;
-    on_complete->Run(ola::rdm::RDM_FAILED_TO_SEND, NULL, packets);
+    RunRDMCallback(on_complete, ola::rdm::RDM_FAILED_TO_SEND);
     delete request;
   }
 }
@@ -712,6 +694,7 @@ void EnttecPort::RunIncrementalDiscovery(
 class EnttecUsbProWidgetImpl : public BaseUsbProWidget {
  public:
     EnttecUsbProWidgetImpl(
+        ola::thread::SchedulerInterface *scheduler,
         ola::io::ConnectedDescriptor *descriptor,
         const EnttecUsbProWidget::EnttecUsbProWidgetOptions &options);
     ~EnttecUsbProWidgetImpl();
@@ -729,6 +712,9 @@ class EnttecUsbProWidgetImpl : public BaseUsbProWidget {
     typedef vector<EnttecUsbProWidget::EnttecUsbProPortAssignmentCallback*>
       PortAssignmentCallbacks;
 
+    ola::thread::SchedulerInterface *m_scheduler;
+    ola::thread::timeout_id m_watchdog_timer_id;
+
     vector<EnttecPort*> m_ports;
     vector<EnttecPortImpl*> m_port_impls;
     auto_ptr<EnttecPortImpl::SendCallback> m_send_cb;
@@ -745,6 +731,8 @@ class EnttecUsbProWidgetImpl : public BaseUsbProWidget {
                  bool enable_rdm);
     void EnableSecondPort();
 
+    bool Watchdog();
+
     static const uint8_t PORT_ASSIGNMENT_LABEL = 141;
     static const uint8_t SET_PORT_ASSIGNMENT_LABEL = 145;
 };
@@ -755,9 +743,12 @@ class EnttecUsbProWidgetImpl : public BaseUsbProWidget {
  * This also works for the RDM Pro with the standard firmware loaded.
  */
 EnttecUsbProWidgetImpl::EnttecUsbProWidgetImpl(
+  ola::thread::SchedulerInterface *scheduler,
   ola::io::ConnectedDescriptor *descriptor,
   const EnttecUsbProWidget::EnttecUsbProWidgetOptions &options)
     : BaseUsbProWidget(descriptor),
+      m_scheduler(scheduler),
+      m_watchdog_timer_id(ola::thread::INVALID_TIMEOUT),
       m_send_cb(NewCallback(this, &EnttecUsbProWidgetImpl::SendCommand)),
       m_uid(options.esta_id ? options.esta_id :
                               EnttecUsbProWidget::ENTTEC_ESTA_ID,
@@ -770,6 +761,9 @@ EnttecUsbProWidgetImpl::EnttecUsbProWidgetImpl(
             options.enable_rdm);
     EnableSecondPort();
   }
+  m_watchdog_timer_id = m_scheduler->RegisterRepeatingTimeout(
+    TimeInterval(1, 0),
+    NewCallback(this, &EnttecUsbProWidgetImpl::Watchdog));
 }
 
 
@@ -799,14 +793,21 @@ void EnttecUsbProWidgetImpl::GetPortAssignments(
  * Stop this widget
  */
 void EnttecUsbProWidgetImpl::Stop() {
+  if (m_watchdog_timer_id != ola::thread::INVALID_TIMEOUT) {
+    m_scheduler->RemoveTimeout(m_watchdog_timer_id);
+    m_watchdog_timer_id = ola::thread::INVALID_TIMEOUT;
+  }
+
   vector<EnttecPortImpl*>::iterator iter = m_port_impls.begin();
-  for (; iter != m_port_impls.end(); ++iter)
+  for (; iter != m_port_impls.end(); ++iter) {
     (*iter)->Stop();
+  }
 
   PortAssignmentCallbacks::iterator cb_iter =
     m_port_assignment_callbacks.begin();
-  for (; cb_iter != m_port_assignment_callbacks.end(); ++cb_iter)
+  for (; cb_iter != m_port_assignment_callbacks.end(); ++cb_iter) {
     (*cb_iter)->Run(false, 0, 0);
+  }
   m_port_assignment_callbacks.clear();
 }
 
@@ -815,8 +816,9 @@ void EnttecUsbProWidgetImpl::Stop() {
  * Given an index, return the EnttecPort
  */
 EnttecPort *EnttecUsbProWidgetImpl::GetPort(unsigned int i) {
-  if (i >= m_ports.size())
+  if (i >= m_ports.size()) {
     return NULL;
+  }
   return m_ports[i];
 }
 
@@ -836,6 +838,8 @@ bool EnttecUsbProWidgetImpl::SendCommand(uint8_t label, const uint8_t *data,
 void EnttecUsbProWidgetImpl::HandleMessage(uint8_t label,
                                            const uint8_t *data,
                                            unsigned int length) {
+  OLA_DEBUG << "Enttec received label " << static_cast<uint32_t>(label)
+            << ", length " << length;
   if (label == PORT_ASSIGNMENT_LABEL) {
     HandlePortAssignment(data, length);
   } else if (label > 128 && m_ports.size() > 1) {
@@ -862,8 +866,8 @@ void EnttecUsbProWidgetImpl::HandleLabel(EnttecPortImpl *port,
   } else if (ops.cos_dmx == label) {
     port->HandleDMXDiff(data, length);
   } else {
-      OLA_WARN << "Unknown message type 0x" << std::hex <<
-        static_cast<int>(label) << ", length " << length;
+      OLA_WARN << "Unknown message type " << ToHex(label) << ", length "
+               << length;
   }
 }
 
@@ -904,8 +908,17 @@ void EnttecUsbProWidgetImpl::AddPort(const OperationLabels &ops,
 
 void EnttecUsbProWidgetImpl::EnableSecondPort() {
   uint8_t data[] = {1, 1};
-  if (!SendCommand(SET_PORT_ASSIGNMENT_LABEL, data, sizeof(data)))
+  if (!SendCommand(SET_PORT_ASSIGNMENT_LABEL, data, sizeof(data))) {
     OLA_INFO << "Failed to enable second port";
+  }
+}
+
+bool EnttecUsbProWidgetImpl::Watchdog() {
+  vector<EnttecPortImpl*>::iterator iter = m_port_impls.begin();
+  for (; iter != m_port_impls.end(); ++iter) {
+    (*iter)->ClockWatchdog();
+  }
+  return true;
 }
 
 // EnttecUsbProWidget
@@ -915,9 +928,10 @@ void EnttecUsbProWidgetImpl::EnableSecondPort() {
  * EnttecUsbProWidget Constructor
  */
 EnttecUsbProWidget::EnttecUsbProWidget(
+    ola::thread::SchedulerInterface *scheduler,
     ola::io::ConnectedDescriptor *descriptor,
     const EnttecUsbProWidgetOptions &options) {
-  m_impl = new EnttecUsbProWidgetImpl(descriptor, options);
+  m_impl = new EnttecUsbProWidgetImpl(scheduler, descriptor, options);
 }
 
 
